# flake8: noqa

"""
    VRChat API Documentation


    The version of the OpenAPI document: 1.7.3
    Contact: me@ariesclark.com
    Generated by: https://openapi-generator.tech
"""


__version__ = "1.0.0"

# import ApiClient
from vrchatapi.api_client import ApiClient

# import Configuration
from vrchatapi.configuration import Configuration

# import exceptions
from vrchatapi.exceptions import OpenApiException
from vrchatapi.exceptions import ApiAttributeError
from vrchatapi.exceptions import ApiTypeError
from vrchatapi.exceptions import ApiValueError
from vrchatapi.exceptions import ApiKeyError
from vrchatapi.exceptions import ApiException
